# TeX-Vorlage der Abteilung TGM für die Bachelorarbeit

[![pipeline status](https://tgm-git.jade-hs.de/templates/bachelorthesis/badges/master/pipeline.svg)](https://tgm-git.jade-hs.de/templates/bachelorthesis/commits/master)

Dieses Respository enthält die offizielle Vorlage für die Anfertigung einer Bachelorarbeit der Abteilung Technik und Gesundheit für Menschen der Jade Hochschule. Das Template selbst besteht aus den zwei Style-Files `TGM_template.sty` und `TGM_listings.sty`, während das TeX-Dokument `bachelorarbeit.tex` als Grundlage für den Inhalt der Bachelorarbeit verwendet werden kann. Darin wurden bereits alle nötigen Vorbereitungen für einen direkten Einstieg getroffen – zudem enthält das Dokument zu Beginn wichtige Hinweise und Anmerkungen zur Anfertigung der Bachelorarbeit. **Nutzen Sie Ihren LaTeX-Editor, um das Dokument im Ausgangszustand zu setzen und lesen Sie zunächst die Hinweise, bevor Sie diese durch Ihre eigenen Inhalte ersetzen.**

Alternative: Sie können die aktuelle Version des [Templates im Ausgangszustand hier herunterladen](https://tgm-git.jade-hs.de/templates/bachelorthesis/-/jobs/artifacts/master/raw/bachelorarbeit.pdf?job=build_pdfs).

## Versionskontrolle

Wie Sie bereits an der Herkunft der Vorlage erkennen können, wurde diese unter Nutzung von Git versioniert. Auch während Sie selbst an der Bachelorarbeit schreiben, kann es vorkommen, dass neue Änderungen am Template vorgenommen werden, die für Sie interessant sind. Schreiben Sie ihre Inhalte daher möglichst auf einem separaten Branch (das Template selbst wurde auf dem `master`-Branch erstellt), um Aktualisierungen über einen Merge einzufügen. Sollten Sie dies nicht tun, können Sie alternative Ihre Änderungen im `master`-Branch mit Hilfe von `git pull --rebase` auf den aktuellen Commit vom Server neu anwenden. Dies verändert jedoch die Versionshistorie.

Unabhängig davon, ob Sie im Laufe der Arbeit Aktualisierungen des Templates einspielen möchten, sollten Sie von der Versionierung Ihrer Inhalte in Git Gebrauch machen. So behalten Sie bis zum Schluss den Überblick über Ihren Fortschritt, Änderungen und können nicht zuletzt auch mögliche TeX-Kompilierfehler schneller beheben.

## Variablen für den Aufbau der Vorlage

In der Vorlage werden einige Funktionen genutzt, um bestimmte Eigenschaften Ihrer Bachelorarbeit u.a. in der Titelei des Dokuments einzufügen. Sie sind daher zwingend zu definieren und von Ihnen korrekt zu personalisieren. Dazu gehören:

| Befehl | Beschreibung |
| :-------- | :-------- |
| \typeofthesis{Bachelorarbeit}                         | Die Art der Arbeit. So kann die Vorlage prinzipiell auch für z.B. Masterarbeiten genutzt werden.      |
| \dateissued{01.01.2014}                               | Das Datum der Themenausgabe (Startzeitpunkt der Bearbeitungszeit von 8 Wochen)                        |
| \datereturned{01.03.2014}                             | Das Abgabedatum der Arbeit                                                                            |
| \datecolloquium{18.03.2014}                           | Das vorraussichtliche Datum des Kolloquiums                                                           |
| \refereeOne{Frau Prof. Dr. Musterprof}                | Die betreuende Professor_in aus der Abteilung TGM. Sie ist immer als Erstprüfende zu nennen.          |
| \refereeTwo{Herr Dr.-Ing. K. Mustermann}              | Die zweitbetreunde Person aus Ihrer Praxisstelle                                                      |
| \refereeOneCompanyAddress{Jade Hochschule ...}        | **Optional** Die Hochschuladresse der Erstprüfer_in.                                                  |
| \refereeOneCompanyAddress{Muster GmbH\\Musterstr ...} | **Optional** Die Firmenadresse der Zweitprüfer_in.                                                    |
| \author{Berta Musterstudi}                            | Ihr eigener (vollständiger) Name                                                                      |
| \matnumber{6001522}                                   | Ihre Matrikelnummer                                                                                   |
| \title{Supergute Bachelorarbeit}                      | Der Titel Ihrer Bachelorarbeit                                                                        |
| \germanabstract{In dieser Arbeit ...}                 | Deutschsprachige Zusammenfassung Ihrer Bachelorarbeit. Maximal eine halbe Seite lang.                 |
| \englishabstract{This Thesis solves ...}              | *Englischsprachige* Zusammenfassung Ihrer Bachelorarbeit. Maximal eine halbe Seite lang.              |
| \keywords{Bachelorarbeit, tolle Arbeit, ...}          | Schlüssel- oder Stichwörter, über die Ihre Arbeit von der Hochschulbibliothek indiziert werden kann.  |
| \acknowledgements{Ich möchte allen danken, die ...}   | **Optional** Ihre Danksagung an Personen, die Sie bei der Anfertigung unterstützt haben.              |
| \license{Diese Arbeit ist lizenziert unter ...}       | Lizenz, unter der Sie die Weiterverwendung von Auszügen aus der Arbeit erlauben möchten.              |
| \germanconfidentiality{Die Arbeit vertraulich, da …}  | **Optional** Falls Ihr Thema es ausdrücklich erfordert, kommentieren Sie diesen Sperrvermerk ein.     |
| \englishconfidentiality{Die Arbeit vertraulich, da …} | **Optional** Falls Ihr Thema es ausdrücklich erfordert, kommentieren Sie diesen Sperrvermerk ein.     |
| \auxLogo{anderes/logo/als/tgm.eps}                    | **Optional** Falls Sie das Logo Ihres Praxisunternehmens verwenden wollen, geben Sie den Pfad hier an.|



## Auswahl des Stils der Literaturangaben

Die Vorlage ist auf die Angabe von Author-Jahr-Literaturangaben voreingestellt (verallgemeinert meist als *Harvard Stil* bezeichnet). Der für Sie empfohlene Stil hängt gänzlich von Ihren und den Vorlieben Ihrer Betreuer_innen ab. Die Vorlage nutzt das Paket `biblatex` für die Erzeugung des Literaturverzeichnisses. In der Präambel der `bachelorarbeit.tex` finden Sie die folgenden Zeilen für die Einstellung, wobei durch `style=alphabetic` z.B. ein alphabetischer Kürzelstil verwendet werden kann.


```latex
\usepackage[style=authoryear, % <--- Wählen Sie hier!
            backend=biber,%
            hyperref=auto,%
            natbib=true]{biblatex}
\bibliography{literatur}      % <--- this is your .bib file
```


## Beta-Funktion: XeTeX-kompatibles Kompilieren

Die Vorlage kann auf Ihren Wunsch auch mit dem Xe(La)TeX-Compiler gesetzt werden. Dieser ist moderner als pdf(La)TeX und unterstützt z.B. die Einbindung von herkömmlichen Systemschriftarten. Möchten Sie an entsprechenden Stellen in der Bachelorarbeit gern die Hausschrift der Jade Hochschule verwenden, so aktivieren Sie in Ihrem TeX-Editor statt pdf(La)TeX also Xe(La)Tex als Compiler. Einige Editoren erlauben die Compilereinstellung auch über einen *Magic Command* am Beginn von `bachelorarbeit.tex`. Fügen Sie dazu als *allererste* Zeile die folgende ein:

```
%!TEX program = xelatex
```
